==> qt-creator-2.6.2-src.zip: qt-creator-2.6.2-src/src/plugins/macros/actionmacrohandler.h <==
/**************************************************************************
**
** Copyright (c) 2013 Nicolas Arnaud-Cormos
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef MACROSPLUGIN_ACTIONEVENTHANDLER_H
#define MACROSPLUGIN_ACTIONEVENTHANDLER_H

#include "imacrohandler.h"

#include <QSet>

QT_BEGIN_NAMESPACE
class QAction;
class QSignalMapper;
QT_END_NAMESPACE

namespace Macros {
namespace Internal {

class ActionMacroHandler : public IMacroHandler
{
    Q_OBJECT

public:
    ActionMacroHandler();

    bool canExecuteEvent(const MacroEvent &macroEvent);
    bool executeEvent(const MacroEvent &macroEvent);

private:
    void registerCommand(const QString &id);

private slots:
    void addCommand(const QString &id);
    void addActionEvent(const QString &id);

private:
    QSet<QString> m_commandIds;
    QSignalMapper *m_mapper;
};

} // namespace Internal
} // namespace Macros

#endif // MACROSPLUGIN_ACTIONEVENTHANDLER_H

==> qt-creator-2.7.1-src.zip: qt-creator-2.7.1-src/src/plugins/macros/actionmacrohandler.h <==
/**************************************************************************
**
** Copyright (c) 2013 Nicolas Arnaud-Cormos
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef MACROSPLUGIN_ACTIONEVENTHANDLER_H
#define MACROSPLUGIN_ACTIONEVENTHANDLER_H

#include "imacrohandler.h"

#include <coreplugin/id.h>
#include <coreplugin/actionmanager/actionmanager.h>

#include <QSet>

QT_BEGIN_NAMESPACE
class QSignalMapper;
QT_END_NAMESPACE

namespace Macros {
namespace Internal {

class ActionMacroHandler : public IMacroHandler
{
    Q_OBJECT

public:
    ActionMacroHandler();

    bool canExecuteEvent(const MacroEvent &macroEvent);
    bool executeEvent(const MacroEvent &macroEvent);

private:
    void registerCommand(Core::Id id);
    Core::Command *command(const QString &id);

private slots:
    void addCommand(const QString &id);
    void addActionEvent(const QString &id);

private:
    QSet<Core::Id> m_commandIds;
    QSignalMapper *m_mapper;
};

} // namespace Internal
} // namespace Macros

#endif // MACROSPLUGIN_ACTIONEVENTHANDLER_H
